:code:`agox convert`
=============

.. note:: 

   The most up to date help for :code:`agox convert` is available through `agox convert --help`.

Simple tool to convert one or more database files to a ASE trajectory :code:`.traj`-file.

.. code-block:: console

    agox convert <database_files> -n <traj_file_name.traj>

